@@ -47,14 +47,8 @@ K_PLUGIN_FACTORY(SambaUserSharePluginFactory, registerPlugin<SambaUserSharePlugi
 // copied from kio/src/core/ksambashare.cpp, KSambaSharePrivate::isSambaInstalled()
 static bool isSambaInstalled()
 {
-    if (QFile::exists(QStringLiteral("/usr/sbin/smbd"))
-            || QFile::exists(QStringLiteral("/usr/local/sbin/smbd"))) {
-        return true;
-    }
-
-    //qDebug() << "Samba is not installed!";
-
-    return false;
+    return QFile::exists(QStringLiteral("/usr/sbin/smbd"))
+           || QFile::exists(QStringLiteral("/usr/local/sbin/smbd"));
 }
 
 SambaUserSharePlugin::SambaUserSharePlugin(QObject *parent, const QList<QVariant> &args)
@@ -62,13 +56,13 @@ SambaUserSharePlugin::SambaUserSharePlugin(QObject *parent, const QList<QVariant
     , m_url(properties->item().mostLocalUrl().toLocalFile())
     , shareData()
 {
-    Q_UNUSED(args);
+    Q_UNUSED(args)
 
     if (m_url.isEmpty()) {
         return;
     }
 
-    QFileInfo pathInfo(m_url);
+    const QFileInfo pathInfo(m_url);
     if (!pathInfo.permission(QFile::ReadUser | QFile::WriteUser)) {
         return;
     }
@@ -128,7 +122,7 @@ SambaUserSharePlugin::SambaUserSharePlugin(QObject *parent, const QList<QVariant
     vLayoutMaster->addWidget(m_shareWidgets);
     propertiesUi.setupUi(m_shareWidgets);
 
-    QList<KSambaShareData> shareList = KSambaShare::instance()->getSharesByPath(m_url);
+    const QList<KSambaShareData> shareList = KSambaShare::instance()->getSharesByPath(m_url);
 
     if (!shareList.isEmpty()) {
         shareData = shareList.at(0); // FIXME: using just the first in the list for a while
@@ -148,7 +142,7 @@ SambaUserSharePlugin::SambaUserSharePlugin(QObject *parent, const QList<QVariant
             this, [=] { setDirty(); });
     connect(propertiesUi.sambaStatusMonitorButton, &QPushButton::clicked,
             this, [] {
-                KToolInvocation::kdeinitExec(QStringLiteral("kcmshell5"), QStringList() << QStringLiteral("smbstatus"));
+                KToolInvocation::kdeinitExec(QStringLiteral("kcmshell5"), {QStringLiteral("smbstatus")});
             });
 
     for (int i = 0; i < model->rowCount(); ++i) {
@@ -170,7 +164,7 @@ SambaUserSharePlugin::~SambaUserSharePlugin()
 #ifdef SAMBA_INSTALL
 void SambaUserSharePlugin::installSamba()
 {
-    QString package = QStringLiteral(SAMBA_PACKAGE_NAME);
+    const QString package = QStringLiteral(SAMBA_PACKAGE_NAME);
     QStringList distroSambaPackages = package.split(QLatin1Char(','));
 
     PackageKit::Transaction *transaction = PackageKit::Daemon::resolve(distroSambaPackages, PackageKit::Transaction::FilterArch);
@@ -178,7 +172,8 @@ void SambaUserSharePlugin::installSamba()
     QSharedPointer<QStringList> pkgids(new QStringList);
 
     connect(transaction, &PackageKit::Transaction::package,
-            this, [pkgids] (PackageKit::Transaction::Info /*info*/, const QString& packageId, const QString& /*summary*/) { pkgids->append(packageId); });
+            this, [pkgids](PackageKit::Transaction::Info /*info*/, const QString &packageId,
+                           const QString & /*summary*/) { pkgids->append(packageId); });
 
     connect(transaction, &PackageKit::Transaction::finished,
             this, [this, pkgids] (PackageKit::Transaction::Exit exit) {
@@ -198,7 +193,7 @@ void SambaUserSharePlugin::installSamba()
 
 void SambaUserSharePlugin::packageFinished(PackageKit::Transaction::Exit status, uint runtime)
 {
-    Q_UNUSED(runtime);
+    Q_UNUSED(runtime)
     if (status == PackageKit::Transaction::ExitSuccess) {
         m_installSambaWidgets->hide();
         m_failedSambaWidgets->hide();
@@ -213,7 +208,8 @@ void SambaUserSharePlugin::packageFinished(PackageKit::Transaction::Exit status,
 
 void SambaUserSharePlugin::reboot()
 {
-    QDBusInterface interface(QStringLiteral("org.kde.ksmserver"), QStringLiteral("/KSMServer"), QStringLiteral("org.kde.KSMServerInterface"), QDBusConnection::sessionBus());
+    QDBusInterface interface(QStringLiteral("org.kde.ksmserver"), QStringLiteral("/KSMServer"),
+                             QStringLiteral("org.kde.KSMServerInterface"), QDBusConnection::sessionBus());
     interface.asyncCall(QStringLiteral("logout"), 0, 1, 2); // Options: do not ask again | reboot | force
 }
 #endif // SAMBA_INSTALL
@@ -234,7 +230,7 @@ void SambaUserSharePlugin::setupViews()
 void SambaUserSharePlugin::load()
 {
     bool guestAllowed = false;
-    bool sambaShared = KSambaShare::instance()->isDirectoryShared(m_url);
+    const bool sambaShared = KSambaShare::instance()->isDirectoryShared(m_url);
 
     propertiesUi.sambaChk->setChecked(sambaShared);
     toggleShareStatus(sambaShared);
@@ -249,8 +245,6 @@ void SambaUserSharePlugin::load()
 
 void SambaUserSharePlugin::applyChanges()
 {
-    KSambaShareData::UserShareError result;
-
     if (propertiesUi.sambaChk->isChecked()) {
         if (shareData.setAcl(model->getAcl()) != KSambaShareData::UserShareAclOk) {
             return;
@@ -262,14 +256,14 @@ void SambaUserSharePlugin::applyChanges()
 
         KSambaShareData::GuestPermission guestOk(shareData.guestPermission());
 
-        guestOk = (propertiesUi.sambaAllowGuestChk->isChecked() == false)
+        guestOk = !propertiesUi.sambaAllowGuestChk->isChecked()
                   ? KSambaShareData::GuestsNotAllowed : KSambaShareData::GuestsAllowed;
 
         shareData.setGuestPermission(guestOk);
 
-        result = shareData.save();
+        shareData.save();
     } else if (KSambaShare::instance()->isDirectoryShared(m_url)) {
-        result = shareData.remove();
+        shareData.remove();
     }
 }
 
